---
name: Documentation improvement
about: Report parts of the docs that are wrong or unclear
labels: documentation, bug
---

<!--To help us understand and resolve your issue, please fill out the form to the best of your ability.-->
<!--You can feel free to delete the sections that do not apply.-->

### Problem

<!--
If you are referencing an existing piece of documentation or example please provide a link.

* I found [...] to be unclear because [...]
* [...] made me think that [...] when really it should be [...]
* There is no example showing how to do [...]
-->


### Suggested Improvement

<!--
If you have an idea to improve the documentation please suggest it here

* This line should be be changed to say [...]
* Include a paragraph explaining [...]
* Add a figure showing [...]
-->
